@@ -4,7 +4,7 @@ use 5.008_001;
 use strict;
 use warnings;
 
-our $VERSION = '3.3.1';
+our $VERSION = '3.3.2';
 
 use Carp              ();
 use File::Spec        ();
@@ -415,7 +415,7 @@ sub _load_source {
             }
         }
 
-        my $tmpfile = sprintf('%s.%d.%d', $cachepath, $$, $self);
+        my $tmpfile = sprintf('%s.%d.%d', $cachepath, $$, Scalar::Util::refaddr($self));
 
         if (open my($out), ">:raw", $tmpfile) {
             my $mtime = $self->_save_compiled($out, $asm, $fullpath, utf8::is_utf8($source));
@@ -663,7 +663,7 @@ Text::Xslate - Scalable template engine for Perl5
 
 =head1 VERSION
 
-This document describes Text::Xslate version 3.3.1.
+This document describes Text::Xslate version 3.3.2.
 
 =head1 SYNOPSIS
 
